aboutsummaryrefslogtreecommitdiffstats
path: root/target/linux/ar71xx/files
diff options
context:
space:
mode:
authorRobert Marko <robimarko@gmail.com>2017-10-05 14:26:23 +0200
committerMathias Kresin <dev@kresin.me>2017-10-14 10:48:29 +0200
commit443abb8ccd669db524317d8b797b0d6e4beebd6b (patch)
treec49b6fec22ca0b256afab59d23a46f6ba0839291 /target/linux/ar71xx/files
parent6f008af3f0b30d2af21ad6934c17b0ae69103ecd (diff)
downloadupstream-443abb8ccd669db524317d8b797b0d6e4beebd6b.tar.gz
upstream-443abb8ccd669db524317d8b797b0d6e4beebd6b.tar.bz2
upstream-443abb8ccd669db524317d8b797b0d6e4beebd6b.zip
ar71xx: add support for Mikrotik RB750P-PBr2
Specifications: - SoC: Qualcomm QCA9531 (650MHz) - RAM: 64MB - Storage: 16MB NOR SPI flash - Ethernet: 5x100M (1 PoE in, 4 PoE out) - Outdoor use ready This ethernet router is based on the same platform as the hEX PoE lite. Installation 1. login to the Mikrotik WebUI to backup your licence keys 2. setup a DHCP/BOOTP Server with: * DHCP-Option 66 (TFTP server name) pointing to a local TFTP Server within the same subnet of the DHCP range * DHCP-Option 67 (Bootfile-Name) matching the initramfs filename of the to be booted image 3. connect the port labled internet to your local network 4. keep the reset button pushed down and power on the board The board should load and start the initramfs image from the TFTP Server. Login as root/without password to the started LEDE via ssh listing on IPv4 address 192.168.1.1. Use sysupgrade to install LEDE. Revert to RouterOS Use the "rbcfg" package on in LEDE: * rbcfg set boot_protocol bootp * rbcfg set boot_device ethnand * rbcfg apply Open Netinstall and reboot routerboard. Now netinstall sees routerboard and you can install RouterOS. If NetInstall gets stuck on Sending offer just wait for it to timeout and then close and open Netinstall again. Click on install again. In order for RouterOS to function properly, you need to restore license for the device. You can do that by including license in NetInstall Signed-off-by: Robert Marko <robimarko@gmail.com>
Diffstat (limited to 'target/linux/ar71xx/files')
-rw-r--r--target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt1
-rw-r--r--target/linux/ar71xx/files/arch/mips/ath79/mach-rbspi.c8
2 files changed, 8 insertions, 1 deletions
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt b/target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt
index 173de346f1..454aee6268 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt
+++ b/target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt
@@ -1008,6 +1008,7 @@ config ATH79_MACH_RBSPI
MikroTik RouterBOARD hAP ac lite
MikroTik RouterBOARD hEX PoE lite
MikroTik RouterBOARD hEX lite
+ MikroTik RouterBOARD Powerbox
MikroTik RouterBOARD LHG 5
MikroTik RouterBOARD cAP (EXPERIMENTAL)
MikroTik RouterBOARD mAP (EXPERIMENTAL)
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/mach-rbspi.c b/target/linux/ar71xx/files/arch/mips/ath79/mach-rbspi.c
index 58e3138b5d..4cdc171de1 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/mach-rbspi.c
+++ b/target/linux/ar71xx/files/arch/mips/ath79/mach-rbspi.c
@@ -7,6 +7,7 @@
* - MikroTik RouterBOARD 952Ui-5ac2nD
* - MikroTik RouterBOARD 962UiGS-5HacT2HnT
* - MikroTik RouterBOARD 750UP r2
+ * - MikroTik RouterBOARD 750P-PBr2
* - MikroTik RouterBOARD 750 r2
* - MikroTik RouterBOARD LHG 5nD
*
@@ -763,7 +764,8 @@ static void __init rb952_setup(void)
* Init the hEX (PoE) lite hardware (QCA953x).
* The 750UP r2 (hEX PoE lite) is nearly identical to the hAP, only without
* WLAN. The 750 r2 (hEX lite) is nearly identical to the 750UP r2, only
* without USB and POE. It shares the same bootloader board identifier.
*/
static void __init rb750upr2_setup(void)
{
@@ -776,6 +778,10 @@ static void __init rb750upr2_setup(void)
if (strstr(mips_get_machine_name(), "750UP r2"))
flags |= RBSPI_HAS_USB | RBSPI_HAS_POE;
+ /* differentiate the Powerbox from the hEX lite */
+ else if (strstr(mips_get_machine_name(), "750P r2"))
+ flags |= RBSPI_HAS_POE;
+
rbspi_952_750r2_setup(flags);
}
@@ -763,7 +764,8 @@ static void __init rb952_setup(void)
* The 750UP r2 (hEX PoE lite) is nearly identical to the hAP, only without
* WLAN. The 750 r2 (hEX lite) is nearly identical to the 750UP r2, only
- * without USB and POE. It shares the same bootloader board identifier.
+ * without USB and POE. The 750P Pbr2 (Powerbox) is nearly identical to hEX PoE
+ * lite, only without USB. It shares the same bootloader board identifier.
*/
static void __init rb750upr2_setup(void)